==> kplatforms-6.x-1.0.tar.gz: kplatforms/kplatforms.sh <==
#!/bin/bash
# This script creates an Aegir platform, from the download up to the front-end.

#****************************************
# Variables
#****************************************

# The name of this file.
THIS_FILE=$(echo $0 | awk -F/ '{print $NF}')

# The path of this file.
THIS_PATH=$(echo $0 | awk -F/ 'BEGIN{FS=OFS="/"}{$NF=""; NF--; print}')

# Requirements
REQ_USER="aegir"
REQ_DRUSH_VERSION="4.5"
REQ_DRUSH_MAKE_VERSION="2.3"

# Files
README_FILE="README.txt"
FAVICON_FILE="favicon.ico"

# Detecting warnings.
WARNING=0

#****************************************
# Arguments
#****************************************

# Default variables.
DISTRO="drupal"                         # Platform distribution type.
DRUSH="drush"                           # Path to the command "drush".
HOSTMASTER="hostmaster"                 # To use like "drush @hostmaster ...".
PATH_PLATFORMS="/var/aegir/platforms"   # Path where to create platforms.
PLATFORM_NAME="$DISTRO"                 # The name of the platform.

# Processing arguments and defining variables.
while getopts ":a:D:d:fh:n:p:s:" opt; do
  case $opt in

    a) # -a htpasswd-file
      HTPASSWD="$OPTARG"
      ;;

    D) # -D drush-command
      DRUSH="$OPTARG"
      ;;

    d) # -d distribution
      DISTRO=$(echo $OPTARG | tr '[:upper:]' '[:lower:]')
      ;;

    f)
      FORCE_COMPLETE=1
      ;;

    h) # -h hostmaster-instance-name
      HOSTMASTER="$OPTARG"
      ;;

    n) # -n platform-name
      PLATFORM_NAME="$OPTARG"
      ;;

    p) # -p path-to-platforms
      PATH_PLATFORMS="$OPTARG"
      ;;

    s) # -s platform-state
      PLATFORM_STATE="$OPTARG"
      ;;

    \?)
      echo "ERROR: Invalid option: -$OPTARG"
      exit 1
      ;;

    :)
      echo "ERROR: Option -$OPTARG requires an argument."
      exit 1
      ;;

  esac
done

#****************************************
# Checking requirements
#****************************************

# User

USER=$(id -nu)
echo "Current user = '$USER'"

if [ "$USER" != "$REQ_USER" ] ; then
  echo "ERROR: You must run '$THIS_FILE' as user '$REQ_USER'."
  exit 1
fi

# Drush version

DRUSH_VERSION=$($DRUSH --version | awk '{print $NF}')
echo "Current 'drush' version = '$DRUSH_VERSION'"

if [ $(echo "$DRUSH_VERSION < $REQ_DRUSH_VERSION" | bc) -eq 1 ]; then
  echo "ERROR: 'Drush' version must be '$REQ_DRUSH_VERSION' or higher."
  exit 1
fi

# Drush make version

DRUSH_MAKE_VERSION=$($DRUSH make --version | awk '{print $NF}')
echo "Current 'drush make' version = '$DRUSH_MAKE_VERSION'"

if [ $(echo "$DRUSH_MAKE_VERSION < $REQ_DRUSH_MAKE_VERSION" | bc) -eq 1 ]; then
  echo "ERROR: 'Drush make' version must be '$REQ_DRUSH_MAKE_VERSION' or higher."
  exit 1
fi

#****************************************
# Building platform information
#****************************************

# Today's date.
DATE="$(date +%Y).$(date +%m).$(date +%d)"

# The name of the platform directory without any path.
if [ "$PLATFORM_STATE" = "" ]; then
  PLATFORM_DIRECTORY="$PLATFORM_NAME-build-$DATE"
else
  PLATFORM_DIRECTORY="$PLATFORM_NAME-build-$DATE-$PLATFORM_STATE"
fi

echo "Platform name = '$PLATFORM_DIRECTORY'"

# Absolute path to the platform.
PATH_PLATFORM="$PATH_PLATFORMS/$PLATFORM_DIRECTORY"

echo "Platform path = '$PATH_PLATFORM'"

#****************************************
# Associating distribution to files
#****************************************

# You can overwrite these variables with the "case" below.

# The makefile with its full path.
MAKEFILE="$THIS_PATH/$DISTRO-stub.make"

# Script and command to patch the platform.
RUN_PATCH_CMD="no"                         # Will we run a command to patch the platform ?
PATCH_SCRIPT="$THIS_PATH/drupal-patch.sh"  # The script that would be used.
PATCH_CMD="$PATCH_SCRIPT $PATH_PLATFORM"   # The full command that would be executed.

# Defining variables as per the distribution.
case $DISTRO in

  drupal)
    RUN_PATCH_CMD="yes"
  ;;

  civicrm)
    RUN_PATCH_CMD="yes"
  ;;

esac

echo "Makefile = '$MAKEFILE'"

# Checking if we can read the makefile.
if [ ! -r "$MAKEFILE" ]; then
  echo "ERROR: The makefile for this distribution cannot be read. You are trying to use '$MAKEFILE'."
  exit 1
fi

echo "Patch script = '$PATCH_SCRIPT'"
echo "Patch command = '$PATCH_CMD'"
echo "Run this patch? '$RUN_PATCH_CMD'"

# Checking if we can read the script.
if [ ! -r "$PATCH_SCRIPT" ]; then
  echo "ERROR: The script to patch this distribution cannot be read. You are trying to use '$PATCH_SCRIPT'."
  exit 1
fi

#****************************************
# Drush commands
#****************************************

# Using "drush --force-complete".
if ! [ -z $FORCE_COMPLETE ]; then
  DRUSH="$DRUSH --force-complete"
fi

echo "Drush command = '$DRUSH'"

# Creating platform.
$DRUSH make $MAKEFILE $PATH_PLATFORM && \
  if [ "$RUN_PATCH_CMD" = "yes" ]; then $PATCH_CMD; fi && \
  $DRUSH --root=$PATH_PLATFORM provision-save @platform_$PLATFORM_DIRECTORY --context_type=platform --makefile=$MAKEFILE && \
  $DRUSH @$HOSTMASTER hosting-import @platform_$PLATFORM_DIRECTORY

# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: Platform created successfully in '$PATH_PLATFORM'."
else
  echo "ERROR: Platform not created successfully."
  exit 1
fi

#****************************************
# Access restricted by users (htpasswd)
#****************************************

if [ "$HTPASSWD" != "" ]; then

  # Checking if we can read the htpasswd file.
  if [ ! -r "$HTPASSWD" ]; then
    echo "WARNING: The htpasswd file cannot be read."
    echo "Use: 'htpasswd -b -c $HTPASSWD username password'."
    WARNING=`expr $WARNING +1`
  fi

  # Defining variables.
  HTACCESS_FILE="$PATH_PLATFORM/.htaccess"
  HTACCESS_FILE_HEAD="$PATH_PLATFORM/.htaccess.head"
  HTACCESS_FILE_TMP="$PATH_PLATFORM/.htaccess.tmp"

  # Editing htaccess file.
  echo "# Access restricted by users" >$HTACCESS_FILE_HEAD && \
    echo "AuthUserFile $HTPASSWD" >>$HTACCESS_FILE_HEAD && \
    echo "AuthName 'Authorized people only'" >>$HTACCESS_FILE_HEAD && \
    echo "AuthType Basic" >>$HTACCESS_FILE_HEAD && \
    echo "require valid-user" >>$HTACCESS_FILE_HEAD && \
    echo "" >>$HTACCESS_FILE_HEAD && \
    cat $HTACCESS_FILE_HEAD $HTACCESS_FILE >$HTACCESS_FILE_TMP && \
    mv $HTACCESS_FILE_TMP $HTACCESS_FILE && \
    rm $HTACCESS_FILE_HEAD

  # Test exit code.
  if [ $? -eq 0 ]; then
    echo "OK: Sites on this platform restricted successfully with '$HTPASSWD'."
  else
    echo "ERROR: Sites on this platform not restricted successfully."
    exit 1
  fi

fi

#****************************************
# Platform improvements
#****************************************

# Favicon, for flavour.
cp $FAVICON_FILE $PATH_PLATFORM/
if [ $? -eq 0 ]; then
  echo "OK: Favicon file copied successfully."
else
  echo "WARNING: Favicon file not copied successfully."
  WARNING=`expr $WARNING +1`
fi

#****************************************
# Exiting
#****************************************

if [ $WARNING -eq 0 ]; then
  echo "OK: '$THIS_FILE' terminated successfully."
  exit 0
elif [ $WARNING -eq 1 ]; then
  echo "WARNING: '$THIS_FILE' terminated with $WARNING warning."
  exit $WARNING
else
  echo "WARNING: '$THIS_FILE' terminated with $WARNING warning(s)."
  exit $WARNING
fi

#****************************************
# End
#****************************************

==> kplatforms-6.x-1.1.tar.gz: kplatforms/kplatforms.sh <==
#!/bin/bash
# This script creates an Aegir platform, from the download up to the front-end.

#****************************************
# Variables
#****************************************

# The name of this file.
THIS_FILE=$(echo $0 | awk -F/ '{print $NF}')

# The path of this file.
THIS_PATH=$(echo $0 | awk -F/ 'BEGIN{FS=OFS="/"}{$NF=""; NF--; print}')

# Requirements
REQ_USER="aegir"
REQ_DRUSH_VERSION="4.5"
REQ_DRUSH_MAKE_VERSION="2.3"

# Files
README_FILE="README.txt"
FAVICON_FILE="favicon.ico"

# Detecting warnings.
WARNING=0

#****************************************
# Arguments
#****************************************

# Default variables.
DISTRO="drupal"                         # Platform distribution type.
DRUSH="drush"                           # Path to the command "drush".
HOSTMASTER="hostmaster"                 # To use like "drush @hostmaster ...".
PATH_PLATFORMS="/var/aegir/platforms"   # Path where to create platforms.

# Processing arguments and defining variables.
while getopts ":a:D:d:fh:n:p:s:" opt; do
  case $opt in

    a) # -a htpasswd-file
      HTPASSWD="$OPTARG"
      ;;

    D) # -D drush-command
      DRUSH="$OPTARG"
      ;;

    d) # -d distribution
      DISTRO=$(echo $OPTARG | tr '[:upper:]' '[:lower:]')
      ;;

    f)
      FORCE_COMPLETE=1
      ;;

    h) # -h hostmaster-instance-name
      HOSTMASTER="$OPTARG"
      ;;

    n) # -n platform-name
      PLATFORM_NAME="$OPTARG"
      ;;

    p) # -p path-to-platforms
      PATH_PLATFORMS="$OPTARG"
      ;;

    s) # -s platform-state
      PLATFORM_STATE="$OPTARG"
      ;;

    \?)
      echo "ERROR: Invalid option: -$OPTARG"
      exit 1
      ;;

    :)
      echo "ERROR: Option -$OPTARG requires an argument."
      exit 1
      ;;

  esac
done

# Set the name of the platform if it has not been defined by an argument.
if [ -z $PLATFORM_NAME ]; then
  PLATFORM_NAME="$DISTRO"
fi

#****************************************
# Checking requirements
#****************************************

# User

USER=$(id -nu)
echo "Current user = '$USER'"

if [ "$USER" != "$REQ_USER" ] ; then
  echo "ERROR: You must run '$THIS_FILE' as user '$REQ_USER'."
  exit 1
fi

# Drush version

DRUSH_VERSION=$($DRUSH --version | awk '{print $NF}')
echo "Current 'drush' version = '$DRUSH_VERSION'"

if [ $(echo "$DRUSH_VERSION < $REQ_DRUSH_VERSION" | bc) -eq 1 ]; then
  echo "ERROR: 'Drush' version must be '$REQ_DRUSH_VERSION' or higher."
  exit 1
fi

# Drush make version

DRUSH_MAKE_VERSION=$($DRUSH make --version | awk '{print $NF}')
echo "Current 'drush make' version = '$DRUSH_MAKE_VERSION'"

if [ $(echo "$DRUSH_MAKE_VERSION < $REQ_DRUSH_MAKE_VERSION" | bc) -eq 1 ]; then
  echo "ERROR: 'Drush make' version must be '$REQ_DRUSH_MAKE_VERSION' or higher."
  exit 1
fi

#****************************************
# Building platform information
#****************************************

# Today's date.
DATE="$(date +%Y).$(date +%m).$(date +%d)"

# The name of the platform directory without any path.
if [ "$PLATFORM_STATE" = "" ]; then
  PLATFORM_DIRECTORY="$PLATFORM_NAME-build-$DATE"
else
  PLATFORM_DIRECTORY="$PLATFORM_NAME-build-$DATE-$PLATFORM_STATE"
fi

echo "Platform name = '$PLATFORM_DIRECTORY'"

# Absolute path to the platform.
PATH_PLATFORM="$PATH_PLATFORMS/$PLATFORM_DIRECTORY"

echo "Platform path = '$PATH_PLATFORM'"

#****************************************
# Associating distribution to files
#****************************************

# You can overwrite these variables with the "case" below.

# The makefile with its full path.
MAKEFILE="$THIS_PATH/$DISTRO-stub.make"

# Script and command to patch the platform.
RUN_PATCH_CMD="no"                         # Will we run a command to patch the platform ?
PATCH_SCRIPT="$THIS_PATH/drupal-patch.sh"  # The script that would be used.
PATCH_CMD="$PATCH_SCRIPT $PATH_PLATFORM"   # The full command that would be executed.

# Defining variables as per the distribution.
case $DISTRO in

  drupal)
    RUN_PATCH_CMD="yes"
  ;;

  civicrm)
    RUN_PATCH_CMD="yes"
  ;;

esac

echo "Makefile = '$MAKEFILE'"

# Checking if we can read the makefile.
if [ ! -r "$MAKEFILE" ]; then
  echo "ERROR: The makefile for this distribution cannot be read. You are trying to use '$MAKEFILE'."
  exit 1
fi

echo "Patch script = '$PATCH_SCRIPT'"
echo "Patch command = '$PATCH_CMD'"
echo "Run this patch? '$RUN_PATCH_CMD'"

# Checking if we can read the script.
if [ ! -r "$PATCH_SCRIPT" ]; then
  echo "ERROR: The script to patch this distribution cannot be read. You are trying to use '$PATCH_SCRIPT'."
  exit 1
fi

#****************************************
# Drush commands
#****************************************

# Using "drush --force-complete".
if ! [ -z $FORCE_COMPLETE ]; then
  DRUSH="$DRUSH --force-complete"
fi

echo "Drush command = '$DRUSH'"

# Creating platform.
$DRUSH make $MAKEFILE $PATH_PLATFORM && \
  if [ "$RUN_PATCH_CMD" = "yes" ]; then $PATCH_CMD; fi && \
  $DRUSH --root=$PATH_PLATFORM provision-save @platform_$PLATFORM_DIRECTORY --context_type=platform --makefile=$MAKEFILE && \
  $DRUSH @$HOSTMASTER hosting-import @platform_$PLATFORM_DIRECTORY

# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: Platform created successfully in '$PATH_PLATFORM'."
else
  echo "ERROR: Platform not created successfully."
  exit 1
fi

#****************************************
# Access restricted by users (htpasswd)
#****************************************

if [ "$HTPASSWD" != "" ]; then

  # Checking if we can read the htpasswd file.
  if [ ! -r "$HTPASSWD" ]; then
    echo "WARNING: The htpasswd file cannot be read."
    echo "Use: 'htpasswd -b -c $HTPASSWD username password'."
    WARNING=`expr $WARNING +1`
  fi

  # Defining variables.
  HTACCESS_FILE="$PATH_PLATFORM/.htaccess"
  HTACCESS_FILE_HEAD="$PATH_PLATFORM/.htaccess.head"
  HTACCESS_FILE_TMP="$PATH_PLATFORM/.htaccess.tmp"

  # Editing htaccess file.
  echo "# Access restricted by users" >$HTACCESS_FILE_HEAD && \
    echo "AuthUserFile $HTPASSWD" >>$HTACCESS_FILE_HEAD && \
    echo "AuthName 'Authorized people only'" >>$HTACCESS_FILE_HEAD && \
    echo "AuthType Basic" >>$HTACCESS_FILE_HEAD && \
    echo "require valid-user" >>$HTACCESS_FILE_HEAD && \
    echo "" >>$HTACCESS_FILE_HEAD && \
    cat $HTACCESS_FILE_HEAD $HTACCESS_FILE >$HTACCESS_FILE_TMP && \
    mv $HTACCESS_FILE_TMP $HTACCESS_FILE && \
    rm $HTACCESS_FILE_HEAD

  # Test exit code.
  if [ $? -eq 0 ]; then
    echo "OK: Sites on this platform restricted successfully with '$HTPASSWD'."
  else
    echo "ERROR: Sites on this platform not restricted successfully."
    exit 1
  fi

fi

#****************************************
# Platform improvements
#****************************************

# Favicon, for flavour.
cp $FAVICON_FILE $PATH_PLATFORM/
if [ $? -eq 0 ]; then
  echo "OK: Favicon file copied successfully."
else
  echo "WARNING: Favicon file not copied successfully."
  WARNING=`expr $WARNING +1`
fi

#****************************************
# Exiting
#****************************************

if [ $WARNING -eq 0 ]; then
  echo "OK: '$THIS_FILE' terminated successfully."
  exit 0
elif [ $WARNING -eq 1 ]; then
  echo "WARNING: '$THIS_FILE' terminated with $WARNING warning."
  exit $WARNING
else
  echo "WARNING: '$THIS_FILE' terminated with $WARNING warning(s)."
  exit $WARNING
fi

#****************************************
# End
#****************************************
